@@ -1145,6 +1145,7 @@ stickynotes_save_now (StickyNotesApplet *applet)
 	char *notes_file;
 	xmlDocPtr doc;
 	xmlNodePtr root;
+	WnckHandle *wnck_handle;
 	WnckScreen *wnck_screen;
 	const gchar *title;
 	GtkTextBuffer *buffer;
@@ -1164,8 +1165,6 @@ stickynotes_save_now (StickyNotesApplet *applet)
 	if (applet->notes == NULL) {
 		g_unlink (notes_file);
 		g_free (notes_file);
-
-		applet->save_scheduled = FALSE;
 		return;
 	}
 
@@ -1176,7 +1175,8 @@ stickynotes_save_now (StickyNotesApplet *applet)
 	xmlDocSetRootElement(doc, root);
 	xmlNewProp(root, XML_CHAR("version"), XML_CHAR (VERSION));
 
-	wnck_screen = wnck_screen_get_default ();
+	wnck_handle = wnck_handle_new (WNCK_CLIENT_TYPE_APPLICATION);
+	wnck_screen = wnck_handle_get_default_screen (wnck_handle);
 	wnck_screen_force_update (wnck_screen);
 
 	/* For all sticky notes */
@@ -1196,7 +1196,7 @@ stickynotes_save_now (StickyNotesApplet *applet)
 		gchar *y_str = g_strdup_printf("%d", note->y);
 
 		xid = GDK_WINDOW_XID (gtk_widget_get_window (note->w_window));
-		wnck_win = wnck_window_get (xid);
+		wnck_win = wnck_handle_get_window (wnck_handle, xid);
 
 		if (!g_settings_get_boolean (note->applet->settings, KEY_STICKY) &&
 			wnck_win)
@@ -1254,6 +1254,8 @@ stickynotes_save_now (StickyNotesApplet *applet)
 		g_free(body);
 	}
 
+	g_clear_object (&wnck_handle);
+
 	{
 		char *tmp_file;
 
@@ -1269,8 +1271,6 @@ stickynotes_save_now (StickyNotesApplet *applet)
 
 	g_free (notes_file);
 	xmlFreeDoc(doc);
-
-	applet->save_scheduled = FALSE;
 }
 
 static gboolean
@@ -1279,6 +1279,7 @@ stickynotes_save_cb (gpointer user_data)
   StickyNotesApplet *applet;
 
   applet = STICKY_NOTES_APPLET (user_data);
+  applet->save_timeout_id = 0;
 
   stickynotes_save_now (applet);
 
@@ -1289,10 +1290,12 @@ void
 stickynotes_save (StickyNotesApplet *applet)
 {
   /* If a save isn't already schedules, save everything a minute from now. */
-  if (!applet->save_scheduled) {
-    g_timeout_add_seconds (60, stickynotes_save_cb, applet);
-    applet->save_scheduled = TRUE;
-  }
+  if (applet->save_timeout_id != 0)
+    return;
+
+  applet->save_timeout_id = g_timeout_add_seconds (60,
+                                                   stickynotes_save_cb,
+                                                   applet);
 }
 
 static char *
